pub struct EmbeddingCacheSnapshot {
pub hits: usize,
pub misses: usize,
pub evictions: usize,
pub size_bytes: usize,
}Expand description
Snapshot of cache stats at a point in time (for logging/serialization)
Fields
hits: usizemisses: usizeevictions: usizesize_bytes: usizeTrait Implementations
Sourceimpl Clone for EmbeddingCacheSnapshot
impl Clone for EmbeddingCacheSnapshot
Sourcefn clone(&self) -> EmbeddingCacheSnapshot
fn clone(&self) -> EmbeddingCacheSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmbeddingCacheSnapshot
impl Debug for EmbeddingCacheSnapshot
Sourceimpl<'de> Deserialize<'de> for EmbeddingCacheSnapshot
impl<'de> Deserialize<'de> for EmbeddingCacheSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EmbeddingCacheSnapshot
impl JsonSchema for EmbeddingCacheSnapshot
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EmbeddingCacheSnapshot
impl NotResult for EmbeddingCacheSnapshot
impl NotString for EmbeddingCacheSnapshot
impl RefUnwindSafe for EmbeddingCacheSnapshot
impl Send for EmbeddingCacheSnapshot
impl Sync for EmbeddingCacheSnapshot
impl Unpin for EmbeddingCacheSnapshot
impl UnwindSafe for EmbeddingCacheSnapshot